@@ -27,6 +27,9 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
 
@@ -39,4 +42,3 @@ dbm_dirfno (dbf)
 {
   return (dbf->desc);
 }
-
