@@ -28,6 +28,9 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 #include "extern.h"
 
@@ -40,6 +43,3 @@ delete (key)
 {
   return gdbm_delete (_gdbm_file, key);
 }
-
-
-
